pub struct Output<K, V, T> { /* private fields */ }Expand description
Operator Output
Implementations
Sourceimpl<K, V, T> Output<K, V, T>
impl<K, V, T> Output<K, V, T>
Sourcepub fn send(&mut self, msg: Message<K, V, T>)
pub fn send(&mut self, msg: Message<K, V, T>)
Send a value into this channel. Data messages are distributed as per the partioning function.
System messages are always broadcasted.
Sourcepub fn get_frontier(&self) -> &Option<T>
pub fn get_frontier(&self) -> &Option<T>
Get the frontier on this Sender, i.e the timestamp of the largest
Epoch sent with this sender or None if no Epoch has been sent with
this sender yet